Struct libcnb_test::PrepareContainerContext
source · [−]pub struct PrepareContainerContext<'a> { /* private fields */ }Implementations
sourceimpl<'a> PrepareContainerContext<'a>
impl<'a> PrepareContainerContext<'a>
sourcepub fn expose_port(&mut self, port: u16) -> &mut Self
pub fn expose_port(&mut self, port: u16) -> &mut Self
Exposes a given port of the container to the host machine.
The given port is mapped to a random port on the host machine. Use
ContainerContext::address_for_port to obtain the local port for a mapped port.
sourcepub fn env(
&mut self,
key: impl Into<String>,
value: impl Into<String>
) -> &mut Self
pub fn env(
&mut self,
key: impl Into<String>,
value: impl Into<String>
) -> &mut Self
Inserts or updates an environment variable mapping for the container.
Example
use libcnb_test::{TestConfig, TestRunner};
TestRunner::default().run_test(
TestConfig::new("heroku/builder:22", "test-fixtures/app"),
|context| {
context
.prepare_container()
.envs(vec![("FOO", "FOO_VALUE"), ("BAR", "BAR_VALUE")])
.start_with_default_process(|container| {
// ...
})
},
);sourcepub fn envs<K: Into<String>, V: Into<String>, I: IntoIterator<Item = (K, V)>>(
&mut self,
envs: I
) -> &mut Self
pub fn envs<K: Into<String>, V: Into<String>, I: IntoIterator<Item = (K, V)>>(
&mut self,
envs: I
) -> &mut Self
Adds or updates multiple environment variable mappings for the container.
Example
use libcnb_test::{TestConfig, TestRunner};
TestRunner::default().run_test(
TestConfig::new("heroku/builder:22", "test-fixtures/app"),
|context| {
context
.prepare_container()
.envs(vec![("FOO", "FOO_VALUE"), ("BAR", "BAR_VALUE")])
.start_with_default_process(|container| {
// ...
})
},
);sourcepub fn start_with_default_process<F: FnOnce(ContainerContext<'_>)>(&self, f: F)
pub fn start_with_default_process<F: FnOnce(ContainerContext<'_>)>(&self, f: F)
Creates and starts the container configured by this context using the image’s default CNB process.
See: CNB App Developer Guide: Run a multi-process app - Default process type
Panics
- When the container could not be created
- When the container could not be started
sourcepub fn start_with_default_process_args<F: FnOnce(ContainerContext<'_>), A: IntoIterator<Item = I>, I: Into<String>>(
&self,
args: A,
f: F
)
pub fn start_with_default_process_args<F: FnOnce(ContainerContext<'_>), A: IntoIterator<Item = I>, I: Into<String>>(
&self,
args: A,
f: F
)
Creates and starts the container configured by this context using the image’s default CNB process and given arguments.
See: CNB App Developer Guide: Run a multi-process app - Default process type with additional arguments
Panics
- When the container could not be created
- When the container could not be started
sourcepub fn start_with_process<F: FnOnce(ContainerContext<'_>), P: Into<String>>(
&self,
process: P,
f: F
)
pub fn start_with_process<F: FnOnce(ContainerContext<'_>), P: Into<String>>(
&self,
process: P,
f: F
)
Creates and starts the container configured by this context using the given CNB process.
See: CNB App Developer Guide: Run a multi-process app - Non-default process-type
Panics
- When the container could not be created
- When the container could not be started
sourcepub fn start_with_process_args<F: FnOnce(ContainerContext<'_>), A: IntoIterator<Item = I>, I: Into<String>, P: Into<String>>(
&self,
process: P,
args: A,
f: F
)
pub fn start_with_process_args<F: FnOnce(ContainerContext<'_>), A: IntoIterator<Item = I>, I: Into<String>, P: Into<String>>(
&self,
process: P,
args: A,
f: F
)
Creates and starts the container configured by this context using the given CNB process and arguments.
Panics
- When the container could not be created
- When the container could not be started
sourcepub fn start_with_shell_command<F: FnOnce(ContainerContext<'_>), C: Into<String>>(
&self,
command: C,
f: F
)
pub fn start_with_shell_command<F: FnOnce(ContainerContext<'_>), C: Into<String>>(
&self,
command: C,
f: F
)
Creates and starts the container configured by this context using the given shell command.
The CNB lifecycle launcher will be implicitly used. Environment variables will be set. Uses
/bin/sh as the shell.
See: CNB App Developer Guide: Run a multi-process app - User-provided shell process
Panics
- When the container could not be created
- When the container could not be started